# [CHANGELOG](https://keepachangelog.com/en/1.0.0/)

## 0.0.8

- add load klayout layer properties [PR](https://github.com/gdsfactory/kweb/pull/11)

## 0.0.2

- add CICD [PR](https://github.com/gdsfactory/kweb/pull/4)
